@@ -62,7 +62,7 @@ class SimpleQueryMeta(QueryMeta):
         if self.group_by:
             groups = list(self.group_by)
             for c in self.columns:
-                if c.column_name in groups:
+                if c.column_name in groups and not c.alias:
                     groups.remove(c.column_name)
                 elif c.alias in groups:
                     groups.remove(c.alias)
@@ -90,7 +90,9 @@ class SimpleQueryMeta(QueryMeta):
                     if group_key in cols:
                         query.append_group_by(table.c[group_key])
                     elif group_key in alias:
-                        query.append_group_by(group_key)
+                        aliased_column = [col.build_column(table) for col in self.columns if col.alias == group_key]
+                        assert len(aliased_column) == 1
+                        query.append_group_by(aliased_column[0])
 
             for c in self.columns:
                 query.append_column(c.build_column(table))
@@ -99,7 +101,7 @@ class SimpleQueryMeta(QueryMeta):
 
         if self.filters:
             for filter in self.filters:
-                query.append_whereclause(filter.build_expression())
+                query.append_whereclause(filter.build_expression(table))
 
         if not query.froms:
             query = query.select_from(table)
